#ifndef COMPONENT_FICR_H
#define COMPONENT_FICR_H

/** SOFTWARE API DEFINITION FOR Factor Information Configuration Registers **/

typedef struct {
	__I uint32_t PART; // Offset: 0x00 - Part Code
	__I uint32_t VARIANT; // Offset: 0x04 - Part Variant, Hardware Version and Production Config.
	__I uint32_t PACKAGE; // Offset: 0x08 - Package Option
	__I uint32_t RAM; // Offset: 0x0C - RAM Variant
	__I uint32_t FLASH; // Offset: 0x10 - Flash Variant
	__IO uint32_t UNUSED0[3]; // Offset: 0x14 - Unspecified
} FICR_Info_t;

typedef struct {
	__I uint32_t A0; // Offset: 0x00 - Slope Definition A0
	__I uint32_t A1; // Offset: 0x04 - Slope Definition A1
	__I uint32_t A2; // Offset: 0x08 - Slope Definition A2
	__I uint32_t A3; // Offset: 0x0C - Slope Definition A3
	__I uint32_t A4; // Offset: 0x10 - Slope Definition A4
	__I uint32_t A5; // Offset: 0x14 - Slope Definition A5
	__I uint32_t B0; // Offset: 0x18 - Y-Intercept B0
	__I uint32_t B1; // Offset: 0x1C - Y-Intercept B1
	__I uint32_t B2; // Offset: 0x20 - Y-Intercept B2
	__I uint32_t B3; // Offset: 0x24 - Y-Intercept B3
	__I uint32_t B4; // Offset: 0x28 - Y-Intercept B4
	__I uint32_t B5; // Offset: 0x2C - Y-Intercept B5
	__I uint32_t T0; // Offset: 0x30 - Segment End T0
	__I uint32_t T1; // Offset: 0x34 - Segment End T1
	__I uint32_t T2; // Offset: 0x38 - Segment End T2
	__I uint32_t T3; // Offset: 0x3C - Segment End T3
	__I uint32_t T4; // Offset: 0x40 - Segment End T4
} FICR_Temp_t;

typedef struct {
	__I uint32_t TAGHEADER0; // Offset: 0x00 - Default Header for NFC Tag
	__I uint32_t TAGHEADER1; // Offset: 0x04 - Default Header for NFC Tag
	__I uint32_t TAGHEADER2; // Offset: 0x08 - Default Header for NFC Tag
	__I uint32_t TAGHEADER3; // Offset: 0x0C - Default Header for NFC Tag
} FICR_NFC_t;

typedef struct {
	__I uint32_t RESERVED0[4];
	__I uint32_t CODEPAGESIZE; // Offset: 0x010 - Code Memory Page Size
	__I uint32_t CODESIZE; // Offset: 0x014 - Code Memory Size
	__I uint32_t RESERVED1[18];
	__I uint32_t DEVICEID[2]; // Offset: 0x060 - Device Identifier
	__I uint32_t RESERVED2[6];
	__I uint32_t ER[4]; // Offset: 0x080 - Encryption Root
	__I uint32_t IR[4]; // Offset: 0x090 - Identity Root
	__I uint32_t DEVICEADDRTYPE; // Offset: 0x0A0 - Device Address Type
	__I uint32_t DEVICEADDR[2]; // Offset: 0x0A4 - Device Address
	__I uint32_t RESERVED3[21];
	FICR_Info_t INFO; // Offset: 0x100 - Device Information
	__I uint32_t RESERVED4[185];
	FICR_Temp_t TEMPERATURE; // Offset: 0x404 - Factory Temp. Sensor Linearization Coefficient Registers
	__I uint32_t RESERVED5[2];
	FICR_NFC_t NFCT; // Offset: 0x450 - Factory NFC Tag Headers
} FICR_t;

#endif
