#ifndef COMPONENT_GPIO_H
#define COMPONENT_GPIO_H

/** SOFTWARE API DEFINITION FOR General-Purpose Input/Output (GPIO) **/

typedef struct {
	__I uint32_t RESERVED0[321];
	__IO uint32_t OUT; // Offset: 0x504 - Write GPIO Port
	__IO uint32_t OUTSET; // Offset: 0x508 - Set Individual GPIO Bits
	__IO uint32_t OUTCLR; // Offset: 0x50C - Clear Individual GPIO Bits
	__I uint32_t IN; // Offset: 0x510 - Read GPIO Port
	__IO uint32_t DIR; // Offset: 0x514 - GPIO Pin Direction Register
	__IO uint32_t DIRSET; // Offset: 0x518 - GPIO Pin Direction Set Register
	__IO uint32_t DIRCLR; // Offset: 0x51C - GPIO Pin Direction Clear Register
	__IO uint32_t LATCH; // Offset: 0x520 - GPIO Pin PIN_CNF[x].SENSE Match Register
	__IO uint32_t DETECTMODE; // Offset: 0x524 - Selection of DETECT Signal Behavior and LDETECT Mode
	__I uint32_t RESERVED1[118];
	__IO uint32_t PIN_CNF[32]; // Offset: 0x700 - GPIO Pin Configuration Registers
} GPIO_t;

/* PIN_CNF - GPIO Pin Configuration Registers */
#define GPIO_PIN_CNF_SENSE_Pos 16
#define GPIO_PIN_CNF_NOSENSE (0UL) // pin sense disabled
#define GPIO_PIN_CNF_DRIVE_Pos 8
#define GPIO_PIN_CNF_DRIVE_S0S1 (0UL) // standard '0', standard '1'
#define GPIO_PIN_CNF_DRIVE_H0H1 (3UL) // high '0', high '1'
#define GPIO_PIN_CNF_PULL_Pos 2
#define GPIO_PIN_CNF_NOPULL (0UL) // no pull-up/pull-down resistor configuration
#define GPIO_PIN_CNF_PULLDOWN (1UL) // pull-down resistor enabled
#define GPIO_PIN_CNF_PULLUP (2UL) // pull-up resistor enabled
#define GPIO_PIN_CNF_INPUT_Pos 1
#define GPIO_PIN_CNF_INPUT_CONNECT (0UL) // connect input buffer
#define GPIO_PIN_CNF_INPUT_DISCONNECT (1UL) // disconnect input buffer
#define GPIO_PIN_CNF_DIR_Pos 0
#define GPIO_PIN_CNF_DIR_INPUT (0UL) // configure pin as input pin
#define GPIO_PIN_CNF_DIR_OUTPUT (1UL) // configure pin as output pin

#endif
