#ifndef UTIL_H
#define UTIL_H

/**
 * @brief Configures the specified pin to behave either as an input or an output.
 * @param[in] pin  The pin to set.
 * @param[in] mode  The direction mode to set on the pin.
 */
void setPinMode(uint8_t pin, uint8_t mode);

/**
 * @brief Set the value of the pin to 1 or 0.
 * @details If the pin has been configured as an output with setPinMode(), it's voltage will be set
 * to the corresponding value: 3.3V for 1, 0V (ground) for 0.
 *
 * If the pin is configured as an input, writing a 1 value will enable an internal 20K pull-up
 * resistor. Writing 0 will disable the pull-up.
 * @param[in] pin  The pin to set.
 * @param[in] value  The value to set on the pin.
 */
void setPinValue(uint8_t pin, uint8_t value);

#endif
